// SPDX-License-Identifier: MIT

use axum::Router;
use std::net::SocketAddr;

use crate::args::args;

mod tls;

#[cfg(any(feature = "tls", feature = "rustls"))]
mod dual;
#[cfg(any(feature = "tls", feature = "rustls"))]
mod http_either;
#[cfg(any(feature = "tls", feature = "rustls"))]
mod upgrade_http;

pub async fn run_server(app: Router) {
    let addr = args().listen_addr;
    match tls::bind(addr).await {
        Ok(server) => {
            tracing::debug!("Listening on {} as tls", addr);
            server
                .serve(app.into_make_service_with_connect_info::<SocketAddr>())
                .await
                .unwrap()
        }
        Err(e) => {
            tracing::info!(
                "Could not start tls server, falling back to plain text on {}: {:?}",
                addr,
                e
            );
            axum_server::bind(addr)
                .serve(app.into_make_service_with_connect_info::<SocketAddr>())
                .await
                .unwrap();
        }
    }
}
