#!/bin/sh

. "$(dirname "$0")/common"

connections_list() {
	local lo

	req_bearer "/api/connections" \
		|| error "Could not list connections"

	lo=$(jq '.connections[] | select(.name == "lo")' < req)
	[ -n "$lo" ] || error "No 'lo' connection?"
	[ "$(echo "$lo" | jq -r .state)" = "activated" ] \
		|| error "lo state not 'activated'"
	[ "$(echo "$lo" | jq -r .ctype)" = "loopback" ] \
		|| error "lo ctype not 'loopback'"
	[ "$(echo "$lo" | jq -r .device)" = "lo" ] \
		|| error "lo device not 'lo'"
}

connections_get() {
	req_bearer "/api/connections/Wired%20connection%201" \
		|| error "Could not get 'Wired connection 1' details"
	[ "$(jq -r .state < req)" = "activated" ] \
		|| error "Wired connection 1 state not 'activated'"
	[ "$(jq -r .ctype < req)" = "802-3-ethernet" ] \
		|| error "Wired connection 1 ctype not '802-3-ethernet'"
	[ "$(jq -r .device < req)" = "eth0" ] \
		|| error "Wired connection 1 device not 'eth0'"
	[ "$(jq -r '.props."GENERAL.STATE"' < req)" = "activated" ] \
		|| error "Wired connection 1 doesn't have GENERAL.STATE props?"
}

connections_patch_form() {
	req_bearer "/api/connections/Wired%20connection%201" -X PATCH \
			-d "802-3-ethernet.wake-on-lan=ignore" \
		|| error "Could not patch Wired connection 1"

	# verify
	req_bearer "/api/connections/Wired%20connection%201" \
		|| error "Could not get 'Wired connection 1:' details"
	[ "$(jq -r '.props."802-3-ethernet.wake-on-lan"' < req)" = "ignore" ] \
		|| error "802-3-ethernet.wake-on-lan wasn't set"
}

connections_patch_json() {
	req_json "/api/connections/Wired%20connection%201" -X PATCH \
			-d '{ "802-3-ethernet.wake-on-lan": "default"}' \
		|| error "Could not patch Wired connection 1"

	# verify
	req_bearer "/api/connections/Wired%20connection%201" \
		|| error "Could not get 'Wired connection 1' details"
	[ "$(jq -r '.props."802-3-ethernet.wake-on-lan"' < req)" = "default" ] \
		|| error "802-3-ethernet.wake-on-lan wasn't set"
}


run_tests connections_list connections_get || exit

run_tests connections_patch_form connections_patch_json
